<?php

class FS_Textfield extends FS_FieldType
{

  public function __construct()
  {
    parent::__construct('text', 'Text');
    $this->html_class = 'fs-text-linked';
  }
  
  // show the html the field needs
  function show_options($field)
  {
    // editing a field
    if (is_array($field))
    {
      if ($field['text_multi'] != '') $checked_multi = ' checked'; else $checked_multi = '';
      echo
        "<tr style='display: none' class='additional {$this->html_class}'>".
      	'	<th valign="top" scope="row"></th>'.
      	'	<td valign="middle"><input type="checkbox"'.$checked_multi.' name="text-multi" id="tag-text-multi" /><label class="input-label" for="tag-text-multi">Multiple values</label>'.
      	' <p class="description">' . __('users will be able to add multiple values to this field', 'fields') . '</p>'.
      	'</td></tr>';
    }
    // new field form
    else
    {
      echo
      "<div class='form-field form-required additional {$this->html_class} check-row'>".
      '	<input type="checkbox" name="text-multi" id="tag-text-multi" /><label class="input-label" for="tag-text-multi">Multiple values</label>'.
      '</div>';
    }
  }
  
  // fired when new field or edit field forms are submitted
  // modify $field and return
  function save_options($field, $group)
  {
    $field['text_multi'] = get_post_value('text-multi');
    return $field;
  }
  
  // show the field in a write panel / meta box
  function show_field($post, $box, $field)
  {
    if ($field['note'])
      $note = '<p class="description">' . $field['note'] . '</p>';

    echo "<th valign='top' scope='row'><label for='{$field['tag_id']}'>{$field['title']}</label></th>" .
         "<td class='fs-sortable' valign='top'>";
        
    if ($field['text_multi'] != '')
    {
      $field['tag_name'] .= '[]';
      $values = $this->get_values($field);
      
      foreach ($values as $value)
      {
        echo "<div class='fs-multi-row'>" .
             "<input type='text' class='fs-textfield' aria-required='true' value='{$value['value']}' id='{$field['tag_id']}' name='{$field['tag_name']}' />" .
             "<a href='#' tabindex='-1' class='fs-remove-row'><br /></a>" .
             "</div>";
      }
      echo "<div class='fs-add-more-wrap'>$note<a class='button fs-add-more' href='#'>" . __('Add more', 'fields') . '</a>'.
           "</div>";
    }
    else
    {
      $value = maybe_unserialize($field['meta_value']);
      if (is_array($value))
        $value = $value['value'];      
      echo "<div class='fs-row'><input type='text' class='fs-textfield' aria-required='true' value='$value' id='{$field['tag_id']}' name='{$field['tag_name']}' /></div>";
    }
    
    echo "</td>";
  }
  
  // save the field's data when a post/page is added/updated
  function save_field($postID, $field)
  {
    field_delete_meta($postID, $field['key']);
        
    if ($field['text_multi'])
    {
      if (is_array($field['meta_value']))
      {
        $index = 0;
        foreach ($field['meta_value'] as $value)
        {
          $arr = array('order' => $index++, 'value' => esc_attr(stripslashes($value)));
          fs_add_meta($postID, $field['key'], serialize($arr));
        }      
      }
    }
    else
    {
      $value = array('value' => esc_attr(stripslashes($field['meta_value'])));
      //$value->agege();
      !fs_update_meta($postID, $field['key'], serialize($value));
    }
  }

  function get_values($field)
  {
    $meta = fs_get_meta($field['key'], false);
    $values = array();
    if (is_array($meta))
    {
      foreach ($meta as $value)
      {
        $value = maybe_unserialize($value);
        $values[] = $value;
      }
      sort_by_order(&$values);
    }
    else
    {
      $values[] = maybe_unserialize($meta);
    }
    
    if (sizeof($values) == 0)
    {
      $value = array('order' => 0, 'value' => '');
      $values[] = $value;
    }
    
    return $values;
  }
}

?>